@@ -1,6 +1,6 @@
 package Parse::PhoneNumber::ID;
 BEGIN {
-  $Parse::PhoneNumber::ID::VERSION = '0.04';
+  $Parse::PhoneNumber::ID::VERSION = '0.05';
 }
 # ABSTRACT: Parse Indonesian phone numbers
 
@@ -14,7 +14,7 @@ our @ISA       = qw(Exporter);
 our @EXPORT_OK = qw(extract_id_phones parse_id_phone
                     list_id_operators list_id_area_codes);
 
-use Clone::Any qw(clone);
+use Data::Clone qw(clone);
 
 # from: http://id.wikipedia.org/wiki/Daftar_kode_telepon_di_Indonesia
 # last updated: 2011-03-08
@@ -955,7 +955,7 @@ Parse::PhoneNumber::ID - Parse Indonesian phone numbers
 
 =head1 VERSION
 
-version 0.04
+version 0.05
 
 =head1 SYNOPSIS
 
